@@ -10,7 +10,7 @@ SPVM::Net::SSLeay::ASN1_OBJECT - ASN1_OBJECT Data Structure in OpenSSL
 
 =head1 Description
 
-Net::SSLeay::ASN1_OBJECT class in L<SPVM> represents L<ASN1_OBJECT|https://docs.openssl.org/3.3/man3/ASN1_OBJECT_new> data structure in OpenSSL.
+Net::SSLeay::ASN1_OBJECT class in L<SPVM> represents C<ASN1_OBJECT> data structure in OpenSSL.
 
 =head1 Usage
 
@@ -22,7 +22,7 @@ Net::SSLeay::ASN1_OBJECT class in L<SPVM> represents L<ASN1_OBJECT|https://docs.
 
 C<static method new : L<Net::SSLeay::OBJECT|SPVM::Net::SSLeay::OBJECT> ();>
 
-Calls native L<ASN1_OBJECT_new|https://docs.openssl.org/3.3/man3/ASN1_OBJECT_new> function, creates a new  L<Net::SSLeay::OBJECT|SPVM::Net::SSLeay::OBJECT> object, sets the pointer value of the object to the return value of the native function, and returns the new object.
+Calls native L<ASN1_OBJECT_new|https://docs.openssl.org/master/man3/ASN1_OBJECT_new> function, creates a new  L<Net::SSLeay::OBJECT|SPVM::Net::SSLeay::OBJECT> object, sets the pointer value of the object to the return value of the native function, and returns the new object.
 
 Exceptions:
 
@@ -34,7 +34,7 @@ If ASN1_OBJECT_new failed, an exception is thrown with C<eval_error_id> set to t
 
 C<method DESTROY : void ();>
 
-Calls native L<ASN1_OBJECT_free|https://docs.openssl.org/3.1/man3/ASN1_OBJECT_new/> function given the pointer value of the instance if C<no_free> flag of the instance is not a true value.
+Calls native L<ASN1_OBJECT_free|https://docs.openssl.org/master/man3/ASN1_OBJECT_free> function given the pointer value of the instance unless C<no_free> flag of the instance is a true value.
 
 =head1 See Also
 
